<?php
/**
 * @file
 * Batch API integration and import functions.
 */

/**
 * Callback for the batch operations.
 */
function ucsf_profiles_batch() {
  $employee_id = array_unique(preg_split("/[\s,]+/", variable_get('ucsf_profiles_ids', '')));

  $operations = array();

  if (is_array($employee_id)) {
    foreach ($employee_id as $id) {
      $id = str_pad($id, 9, "0", STR_PAD_LEFT);
      $operations[] = array('ucsf_profiles_save_as_json', array($id));
    }
  }

  $batch = array(
    'title' => t('Downloading publications from UCSF Profiles'),
    'operations' => $operations,
    'finished' => 'ucsf_profiles_batch_finished',
    'file' => drupal_get_path('module', 'ucsf_profiles') . '/ucsf_profiles.import.inc',
  );
  batch_set($batch);
  batch_process();
}

/**
 * Save JSON files to system files directory.
 */
function ucsf_profiles_save_as_json($employee_id, &$context) {
  if ($employee_id) {
    $person_id = (int) ($employee_id / 10) + 2569307;
    // JSON URI for the person queried.
    $json_source = 'http://profiles.ucsf.edu/CustomAPI/v1/JSONProfile.aspx?' .
                   'Person=' . $person_id .
                   '&publications=full';

    // Define publications folder to save all JSON files in.
    $pubs_path = file_directory_path()
               . '/'
               . variable_get('ucsf_profiles_pubs_dir', 'ucsf_profiles_publications');

    $handle = '';
    if (file_check_directory($pubs_path, 3)) {
      if ($handle = fopen($json_source, 'r')) {
        $json = stream_get_contents($handle);
        fclose($handle);

        // Save the JSON file. Replace if exists.
        $pubs_file = file_save_data($json, "{$pubs_path}/{$employee_id}_{$person_id}.json", FILE_EXISTS_REPLACE);
      }
    }

    $context['results'][] = t('Retrieved JSON file for Employee ID# @employee_id', array('@employee_id' => $employee_id));
    $context['message'] = t('Downloading JSON file for Employee ID# @employee_id', array('@employee_id' => $employee_id));
  }
}

/**
 * Finished callback of import batch.
 *
 * Reports the number of XML files that processed, and the number of
 * publications retrieved for each person queried, or an error message
 * explaining what went wrong.
 *
 * @param bool $success
 *   Boolean.
 *
 * @param array $results
 *   The array of results gathered so far by the batch processing.
 *
 * @param array $operations
 *   Callback functions defined by the batch.
 */
function ucsf_profiles_batch_finished($success, $results, $operations) {
  if ($success) {
    $message = format_plural(count($results), 'Downloaded one JSON file.', 'Downloaded @count JSON files.');
    variable_set('ucsf_profiles_cron_last', $_SERVER['REQUEST_TIME']);
  }
  else {
    $error_operation = reset($operations);
    $message = 'An error occurred while processing ' . $error_operation[0] . ' with arguments: ' . print_r($error_operation[0], TRUE);
  }
  drupal_set_message(filter_xss(t('!results', array('!results' => $message))));
}
